Module: Google::Cloud::Monitoring::MetricsScope
- Defined in:
- lib/google/cloud/monitoring/metrics_scope.rb,
lib/google/cloud/monitoring/metrics_scope/version.rb
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.monitoring_metrics_scope| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-monitoring-metrics_scope library.
-
.metrics_scopes(version: :v1, &block) ⇒ ::Object
Create a new client object for MetricsScopes.
-
.metrics_scopes_available?(version: :v1) ⇒ boolean
Determines whether the MetricsScopes service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.monitoring_metrics_scope| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-monitoring-metrics_scope library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
140 141 142 143 144 |
# File 'lib/google/cloud/monitoring/metrics_scope.rb', line 140 def self.configure yield ::Google::Cloud.configure.monitoring_metrics_scope if block_given? ::Google::Cloud.configure.monitoring_metrics_scope end |
.metrics_scopes(version: :v1, &block) ⇒ ::Object
Create a new client object for MetricsScopes.
By default, this returns an instance of
Google::Cloud::Monitoring::MetricsScope::V1::MetricsScopes::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the MetricsScopes service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
Raises an exception if the currently installed versioned client gem for the given API version does not support the MetricsScopes service. You can determine whether the method will succeed by calling metrics_scopes_available?.
About MetricsScopes
Manages Cloud Monitoring Metrics Scopes, and the monitoring of Google Cloud projects and AWS accounts.
74 75 76 77 78 79 80 81 82 83 |
# File 'lib/google/cloud/monitoring/metrics_scope.rb', line 74 def self.metrics_scopes version: :v1, &block require "google/cloud/monitoring/metrics_scope/#{version.to_s.downcase}" package_name = Google::Cloud::Monitoring::MetricsScope .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Monitoring::MetricsScope.const_get(package_name).const_get(:MetricsScopes) service_module.const_get(:Client).new(&block) end |
.metrics_scopes_available?(version: :v1) ⇒ boolean
Determines whether the MetricsScopes service is supported by the current client. If true, you can retrieve a client object by calling metrics_scopes. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the MetricsScopes service, or if the versioned client gem needs an update to support the MetricsScopes service.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/google/cloud/monitoring/metrics_scope.rb', line 96 def self.metrics_scopes_available? version: :v1 require "google/cloud/monitoring/metrics_scope/#{version.to_s.downcase}" package_name = Google::Cloud::Monitoring::MetricsScope .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Monitoring::MetricsScope.const_get package_name return false unless service_module.const_defined? :MetricsScopes service_module = service_module.const_get :MetricsScopes service_module.const_defined? :Client rescue ::LoadError false end |